Class: OSCRuby::Configuration
- Inherits:
-
Object
- Object
- OSCRuby::Configuration
- Defined in:
- lib/osc_ruby/configuration.rb
Instance Attribute Summary collapse
-
#interface ⇒ Object
A holder class that holds the configuration information for the OSCRuby::Client block.
-
#password ⇒ Object
A holder class that holds the configuration information for the OSCRuby::Client block.
-
#username ⇒ Object
A holder class that holds the configuration information for the OSCRuby::Client block.
Instance Method Summary collapse
-
#initialize ⇒ Configuration
constructor
A new instance of Configuration.
Constructor Details
#initialize ⇒ Configuration
Returns a new instance of Configuration.
8 9 |
# File 'lib/osc_ruby/configuration.rb', line 8 def initialize end |
Instance Attribute Details
#interface ⇒ Object
A holder class that holds the configuration information for the OSCRuby::Client block
6 7 8 |
# File 'lib/osc_ruby/configuration.rb', line 6 def interface @interface end |
#password ⇒ Object
A holder class that holds the configuration information for the OSCRuby::Client block
6 7 8 |
# File 'lib/osc_ruby/configuration.rb', line 6 def password @password end |
#username ⇒ Object
A holder class that holds the configuration information for the OSCRuby::Client block
6 7 8 |
# File 'lib/osc_ruby/configuration.rb', line 6 def username @username end |